@@ -1,5 +1,5 @@
 package Mojo::Leds::Rest::DBIx;
-$Mojo::Leds::Rest::DBIx::VERSION = '1.03';
+$Mojo::Leds::Rest::DBIx::VERSION = '1.04';
 use Mojo::Base 'Mojo::Leds::Rest';
 use vars qw($AUTOLOAD);
 
@@ -52,7 +52,7 @@ sub _update {
     return $c->_raise_error( 'Element not found', 404 ) unless ($rec);
 
     # annullo tutti i campi
-    $rec->$_(undef) foreach ( grep !/^${pk}$/, keys $c->_rec2json );
+    $rec->$_(undef) foreach ( grep !/^${pk}$/, keys %{$c->_rec2json} );
     while ( my ( $k, $v ) = each %$set ) {
         $rec->$k($v);
     }
@@ -175,7 +175,7 @@ Mojo::Leds::Rest::DBIx - A RESTFul interface to Class::DBIx
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 SYNOPSIS
 
